% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/export.R
\name{h2o.save_mojo}
\alias{h2o.save_mojo}
\title{Save an H2O Model Object as Mojo to Disk}
\usage{
h2o.save_mojo(object, path = "", force = FALSE, filename = "")
}
\arguments{
\item{object}{an \linkS4class{H2OModel} object.}

\item{path}{string indicating the directory the model will be written to.}

\item{force}{logical, indicates how to deal with files that already exist.}

\item{filename}{string indicating the file name. (Type of file is always .zip)}
}
\description{
Save an MOJO (Model Object, Optimized) to disk.
}
\details{
MOJO will download as a zip file. In the case of existing files \code{force = TRUE}
will overwrite the file. Otherwise, the operation will fail.
}
\examples{
\dontrun{
# library(h2o)
# h2o.init()
# prostate <- h2o.uploadFile(path = system.file("extdata", "prostate.csv", package="h2o"))
# prostate_glm <- h2o.glm(y = "CAPSULE", x = c("AGE", "RACE", "PSA", "DCAPS"),
#                         training_frame = prostate, family = "binomial", alpha = 0.5)
# h2o.save_mojo(object = prostate_glm, path = "/Users/UserName/Desktop", force = TRUE)
}
}
\seealso{
\code{\link{h2o.saveModel}} for saving a model to disk as a binary object.
}
